==> reference3-1.0-sources.jar: one/xingyi/reference3/person/server/domain/IPerson.java <==
package one.xingyi.reference3.person.server.domain;
//Made by one.xingyi.core.filemaker.ServerInterfaceFileMaker
//Defn one.xingyi.reference3.person.IPersonDefn
import one.xingyi.core.sdk.IXingYiResource;
import one.xingyi.core.annotations.XingYiGenerated;
import java.lang.String;
import java.lang.Integer;
import one.xingyi.reference3.address.IAddressLine12ViewDefn;
import one.xingyi.reference3.telephone.ITelephoneNumberViewDefn;
public interface IPerson  extends IXingYiResource{
    //PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
    java.lang.String name();
    IPerson withname(java.lang.String name);
    //PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=Integer))
    java.lang.Integer age();
    IPerson withage(java.lang.Integer age);
    //ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference3.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference3.address.server.domain.IAddress, forView=one.xingyi.reference3.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference3.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference3.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
    one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.server.domain.IAddress> addresses();
    IPerson withaddresses(one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.server.domain.IAddress> addresses);
    //ViewType(typeName=one.xingyi.reference3.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference3.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference3.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference3.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference3.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
    one.xingyi.reference3.telephone.server.domain.ITelephoneNumber telephone();
    IPerson withtelephone(one.xingyi.reference3.telephone.server.domain.ITelephoneNumber telephone);
}

==> reference3-1.1-sources.jar: one/xingyi/reference3/person/server/domain/IPerson.java <==
package one.xingyi.reference3.person.server.domain;
//Made by one.xingyi.core.filemaker.ServerInterfaceFileMaker
//Defn one.xingyi.reference3.person.IPersonDefn
import one.xingyi.core.sdk.IXingYiResource;
import one.xingyi.core.annotations.XingYiGenerated;
import java.lang.String;
import java.lang.Integer;
import one.xingyi.reference3.address.IAddressLine12ViewDefn;
import one.xingyi.reference3.telephone.ITelephoneNumberViewDefn;
public interface IPerson  extends IXingYiResource{
    //StringPrimitiveType()
    java.lang.String name();
    IPerson withname(java.lang.String name);
    //IntegerPrimitiveType()
    java.lang.Integer age();
    IPerson withage(java.lang.Integer age);
    //ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference3.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference3.address.server.domain.IAddress, forView=one.xingyi.reference3.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference3.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference3.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
    one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.server.domain.IAddress> addresses();
    IPerson withaddresses(one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.server.domain.IAddress> addresses);
    //ViewType(typeName=one.xingyi.reference3.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference3.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference3.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference3.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference3.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
    one.xingyi.reference3.telephone.server.domain.ITelephoneNumber telephone();
    IPerson withtelephone(one.xingyi.reference3.telephone.server.domain.ITelephoneNumber telephone);
}
